# Changelog

<!--
   You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst
-->

<!-- towncrier release notes start -->

## 1.0.0b4 (2025-11-10)


### New features:

- - Add icons to views @libargutxi
  - Add row spacing configuration @libargutxi
  - Add behavior to set fetchpriority/loading attributes to images @libargutxi
  - Complete translations @erral [#7](https://github.com/codesyntax/cs_dynamicpages/issues/7)

## 1.0.0b3 (2025-10-17)


### New features:

- Add more javascript code to the frontend @libargutxi [#5](https://github.com/codesyntax/cs_dynamicpages/issues/5)
- New configuration options @libargutxi 

## 1.0.0b2 (2025-10-08)


### New features:

- Publish created rows folder @libargutxi [#4](https://github.com/collective/cs_dynamicpages/issues/4)

## 1.0.0b1 (2025-10-08)


### Internal:

- Initial release @codesyntax
